==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/modelio/MDLAxisAlignedBoundingBox.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.modelio;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/MDLAxisAlignedBoundingBox/*</name>*/ 
    extends /*<extends>*/Struct<MDLAxisAlignedBoundingBox>/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class MDLAxisAlignedBoundingBoxPtr extends Ptr<MDLAxisAlignedBoundingBox, MDLAxisAlignedBoundingBoxPtr> {}/*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public MDLAxisAlignedBoundingBox() {}
    public MDLAxisAlignedBoundingBox(VectorFloat3 maxBounds, VectorFloat3 minBounds) {
        this.setMaxBounds(maxBounds);
        this.setMinBounds(minBounds);
    }
    /*</constructors>*/
    /*<properties>*//*</properties>*/
    /*<members>*/
    @StructMember(0) public native VectorFloat3 getMaxBounds();
    @StructMember(0) public native MDLAxisAlignedBoundingBox setMaxBounds(VectorFloat3 maxBounds);
    @StructMember(1) public native VectorFloat3 getMinBounds();
    @StructMember(1) public native MDLAxisAlignedBoundingBox setMinBounds(VectorFloat3 minBounds);
    /*</members>*/
    /*<methods>*//*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/modelio/MDLAxisAlignedBoundingBox.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.modelio;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/MDLAxisAlignedBoundingBox/*</name>*/ 
    extends /*<extends>*/Struct<MDLAxisAlignedBoundingBox>/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class MDLAxisAlignedBoundingBoxPtr extends Ptr<MDLAxisAlignedBoundingBox, MDLAxisAlignedBoundingBoxPtr> {}/*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public MDLAxisAlignedBoundingBox() {}
    public MDLAxisAlignedBoundingBox(VectorFloat3 maxBounds, VectorFloat3 minBounds) {
        this.setMaxBounds(maxBounds);
        this.setMinBounds(minBounds);
    }
    /*</constructors>*/
    /*<properties>*//*</properties>*/
    /*<members>*/
    @StructMember(0) public native @ByVal VectorFloat3 getMaxBounds();
    @StructMember(0) public native MDLAxisAlignedBoundingBox setMaxBounds(@ByVal VectorFloat3 maxBounds);
    @StructMember(1) public native @ByVal VectorFloat3 getMinBounds();
    @StructMember(1) public native MDLAxisAlignedBoundingBox setMinBounds(@ByVal VectorFloat3 minBounds);
    /*</members>*/
    /*<methods>*//*</methods>*/
}
